'use client'
/* eslint-disable */
// Chakra Imports
import {
  Box,
  Breadcrumb,
  BreadcrumbItem,
  BreadcrumbLink,
  Flex,
  Link,
  useColorModeValue
} from '@chakra-ui/react'
import { useState, useEffect } from 'react'
import AdminNavbarLinks from '@/components/navbar/NavbarLinksAdmin'
import { getStorage, isWindowAvailable, setStorage } from '@/utils/navigation'
import { SelectWrapper } from '../fields/Fields';
import { useGeneral } from '@/contexts/GeneralContext';
import { useSession } from 'next-auth/react'
import { useRouter } from "next/navigation";

export default function AdminNavbar(props: {
  secondary: boolean;
  message: string | boolean;
  brandText: string;
  fixed: boolean;
  pathname?: string;
  onOpen: (...args: any[]) => any;
}) {

  const { newProjects, saveProjectId, projectId, currentUser } = useGeneral();
  const [scrolled, setScrolled] = useState(false);
  const { data: session, status, update } = useSession();
  const router = useRouter();

  const isAdmin = (currentUser.roles.includes("Administrator") || currentUser.roles.includes("Project Admin")) ?? false;
  
  useEffect(() => {
    if (isWindowAvailable()) {
      // You now have access to `window`
      window.addEventListener("scroll", changeNavbar);

      return () => {
        window.removeEventListener("scroll", changeNavbar);
      };
    }
  });

  const { secondary, message, brandText } = props;

  // Here are all the props that may change depending on navbar's type or state.(secondary, variant, scrolled)
  let mainText = useColorModeValue("navy.700", "white");
  let secondaryText = useColorModeValue("gray.700", "white");
  let navbarPosition = "fixed" as const;
  let navbarFilter = "none";
  let navbarBackdrop = "blur(20px)";
  let navbarShadow = "none";
  let navbarBg = useColorModeValue("rgba(244, 247, 254, 0.2)", "rgba(11,20,55,0.5)");
  let navbarBorder = "transparent";
  let secondaryMargin = "0px";
  let paddingX = "15px";
  let gap = "0px";
  const changeNavbar = () => {
    if (isWindowAvailable() && window.scrollY > 1) {
      setScrolled(true);
    } else {
      setScrolled(false);
    }
  };

  const handleChange = async (value: string) => {
    setStorage('x-project-id', value?.toString())
    session.currentProjectId = value?.toString();
    await update({
      ...session,
      currentProjectId: value,
    });
    router.push("/admin/dashboard");
    saveProjectId(value?.toString())
  };

  const getProjectId = () => {
    const projectId = session?.currentProjectId ?? getStorage("x-project-id");
    if (projectId) {
      saveProjectId(projectId?.toString())
    }
  }
  useEffect(() => {
    getProjectId();
  }, [session?.currentProjectId])

  return (
    <Box
      position={navbarPosition}
      boxShadow={navbarShadow}
      bg={navbarBg}
      borderColor={navbarBorder}
      filter={navbarFilter}
      backdropFilter={navbarBackdrop}
      backgroundPosition="center"
      backgroundSize="cover"
      borderRadius="16px"
      borderWidth="1.5px"
      borderStyle="solid"
      transitionDelay="0s, 0s, 0s, 0s"
      transitionDuration=" 0.25s, 0.25s, 0.25s, 0s"
      transition-property="box-shadow, background-color, filter, border"
      transitionTimingFunction="linear, linear, linear, linear"
      alignItems={{ xl: "center" }}
      display={secondary ? "block" : "flex"}
      minH="75px"
      justifyContent={{ xl: "center" }}
      lineHeight="25.6px"
      mx="auto"
      mt={secondaryMargin}
      pb="8px"
      right={{ base: "12px", md: "30px", lg: "30px", xl: "30px" }}
      px={{
        sm: paddingX,
        md: "10px",
      }}
      ps={{
        xl: "12px",
      }}
      pt="8px"
      top={{ base: "12px", md: "16px", xl: "18px" }}
      w={{
        base: "calc(100vw - 6%)",
        md: "calc(100vw - 8%)",
        lg: "calc(100vw - 6%)",
        xl: "calc(100vw - 350px)",
        "2xl": "calc(100vw - 365px)",
      }}>
      <Flex
        w="100%"
        flexDirection={{
          sm: "column",
          md: "row",
        }}
        alignItems={{ xl: "center" }}
        mb={gap}>
        <Box mb={{ sm: "8px", md: "0px" }}>
          <Breadcrumb>
            <BreadcrumbItem color={secondaryText} fontSize="sm" mb="5px">
              <BreadcrumbLink href="#" color={secondaryText}>
                Pages
              </BreadcrumbLink>
            </BreadcrumbItem>

            <BreadcrumbItem color={secondaryText} fontSize="sm">
              <BreadcrumbLink href="#" color={secondaryText}>
                {brandText}
              </BreadcrumbLink>
            </BreadcrumbItem>
          </Breadcrumb>
          {/* Here we create navbar brand, based on route name */}
          <Link
            color={mainText}
            href="#"
            bg="inherit"
            borderRadius="inherit"
            fontWeight="bold"
            fontSize="34px"
            _hover={{ color: { mainText } }}
            _active={{
              bg: "inherit",
              transform: "none",
              borderColor: "transparent",
            }}
            _focus={{
              boxShadow: "none",
            }}>
            {brandText}
          </Link>
        </Box>
        <Box ms="auto" display="flex" alignItems="center" w={{ sm: "100%", md: "unset" }}>
          { isAdmin && 
            <Box px="5px">
              <SelectWrapper
                margin={true}
                form={false}
                fieldName="projects"
                id="projects"
                variant="auth"
                w="full"
                defaultValue={projectId}
                fontSize="sm"
                type="text"
                fontWeight="500"
                value={projectId}
                updateOnParent={(e) => handleChange(String(e))}
                options={newProjects?.map((project: any) => ({
                  label: project?.name,
                  value: project?.id,
                }))}
              />
            </Box>
          }
          <AdminNavbarLinks onOpen={props.onOpen} secondary={props.secondary} fixed={props.fixed} />
        </Box>
      </Flex>
    </Box>
  );
}
